@@ -115,6 +115,7 @@ from .phonenumberutil import (COUNTRY_CODE_TO_REGION_CODE, SUPPORTED_REGIONS,
                               national_significant_number,
                               ndd_prefix_for_region,
                               normalize_digits_only,
+                              normalize_diallable_chars_only,
                               number_type,
                               parse,
                               region_code_for_country_code,
@@ -138,7 +139,7 @@ from .phonenumbermatcher import PhoneNumberMatch, PhoneNumberMatcher, Leniency
 
 # Version number is taken from the upstream libphonenumber version
 # together with an indication of the version of the Python-specific code.
-__version__ = "8.1.0"
+__version__ = "8.2.0"
 
 __all__ = ['PhoneNumber', 'CountryCodeSource', 'FrozenPhoneNumber',
            'REGION_CODE_FOR_NON_GEO_ENTITY', 'NumberFormat', 'PhoneNumberDesc', 'PhoneMetadata',
@@ -180,6 +181,7 @@ __all__ = ['PhoneNumber', 'CountryCodeSource', 'FrozenPhoneNumber',
            'national_significant_number',
            'ndd_prefix_for_region',
            'normalize_digits_only',
+           'normalize_diallable_chars_only',
            'number_type',
            'parse',
            'region_code_for_country_code',
